bcl-secunit 0.4.2
secunit binary — agent helper for registry inspection, run orchestration, and capture.
Crate
Builds
Feature flags
Size
Source code size: 292.59 kB
This is the summed size of all the files inside the crates.io package for this release.
Links
Battle-Creek-LLC/secunit
0
0
8
crates.io
Dependencies
anyhow ^1
normal
chrono ^0.4
normal
clap ^4
normal
secunit-capture ^0.4.2
normal
secunit-core ^0.4.2
normal
serde ^1
normal
serde_json ^1
normal
serde_yaml ^0.9
normal
tokio ^1
normal
tracing ^0.1
normal
tracing-subscriber ^0.3
normal
assert_cmd ^2
dev
insta ^1
dev
predicates ^3
dev
tempfile ^3
dev
Versions
0.7.1
(2026-08-01)
0.7.0
(2026-07-31)
0.6.1
(2026-07-24)
0.6.0
(2026-07-23)
0.5.0
(2026-05-30)
0.4.2
(2026-05-27)
0.1.2
(2026-05-10)
Owners
bcl-secunit-0.4.2 is not a library.